secondary property
A support color to primary, with less emphasis than primary, often of same hue as primary, but does not have to be.
Implementation
final Color secondary;
A support color to primary, with less emphasis than primary, often of same hue as primary, but does not have to be.
final Color secondary;