FlexSliderIndicatorType enum

Enum used to select the type of built-in value indicator used by Slider.

The current two options included are Material-2 default RectangularSliderValueIndicatorShape and Material-3 default DropSliderValueIndicatorShape.

The current implementation of the drop in Flutter, at least up and until version 3.24, does not match the official Material-3 specification. More options will be added when they are supported in Flutter.

This enum is used by FlexSubThemes.sliderTheme.

Inheritance
Available extensions

Values

rectangular → const FlexSliderIndicatorType

Used to select RectangularSliderValueIndicatorShape as value indicator in FlexSubThemes.sliderTheme for the Slider widget. For the RangeSlider the corresponding shape RectangularRangeSliderValueIndicatorShape is used.

It is a rounded rectangle with talk bubble pointer to slider thumb.

This is default style for the Material-2 specification and mode.

drop → const FlexSliderIndicatorType

Used to select DropSliderValueIndicatorShape as value indicator in FlexSubThemes.sliderTheme for the Slider widget. For the RangeSlider the corresponding shape PaddleRangeSliderValueIndicatorShape is used. There is no old M3 spec correct drop shape for RangeSlider in Flutter, this is used as the closest available alternative. This version was made before the correct M3 older shape was available. The correct shape for the older M3 shape was never implemented for RangeSlider in Flutter.

It is a like an inverted water drop, or a map pin drop pointing towards the slider thumb.

This is default style for the older Material-3 specification and mode. In Flutter SDK the range slider uses the rectangular shape by default in M3 mode, but FCS uses the PaddleRangeSliderValueIndicatorShape as default for the RangeSlider as it is closer to the older M3 spec than the rectangular shape.

rounded → const FlexSliderIndicatorType

Used to select the RoundedRectSliderValueIndicatorShape for the Slider value indicator in FlexSubThemes.sliderTheme for the Slider widget. For the RangeSlider the corresponding shape RoundedRectRangeSliderValueIndicatorShape is used.

This is the default style for the newer Material-3 specification introduced in December 2023.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FlexSliderIndicatorType>
A constant List of the values in this enum, in order of their declaration.