blendOnColors property

bool blendOnColors
final

Set to true to enable blendOnLevel based onColor blending also on resulting ColorScheme.onPrimary, ColorScheme.onSecondary and ColorScheme.onTertiary colors.

Use blendOnLevel value to in FlexColorScheme themes to also blend in each corresponding ColorScheme color property's color into its onColors.

If blendOnColors is false, the blendOnLevel setting only affects ColorScheme.onSurface, ColorScheme.onPrimaryContainer, ColorScheme.onSecondaryContainer, ColorScheme.onTertiaryContainer and ColorScheme.onErrorContainer.

If blendOnColors is true, it also impacts ColorScheme.onPrimary, ColorScheme.onSecondary, ColorScheme.onTertiary and ColorScheme.onError.

Blending the on colors results in lower contrast than when not doing so, but it works well on lower blend levels. The effect can be adjusted with blendOnLevel and completely turned off by setting blendOnLevel to 0 (zero).

Defaults to false.

Consider setting this property true in dark mode, and false in light theme mode, for a style that matches the Material-3 color design when not using seed generated ColorScheme.

Implementation

final bool blendOnColors;