FlexSurfaceMode enum

Enum for using predefined surface blend modes for all surfaces and scaffold background colors in FlexColorScheme based themes.

Inheritance
Available extensions

Values

level → const FlexSurfaceMode

All surfaces have same alpha blend level including scaffold background.

The blend level is at equal strength as set by blendLevel, the blend strength mix definition is:

  • Surface & dialogs (1x)
  • Scaffold background (1x)
highBackgroundLowScaffold → const FlexSurfaceMode

Decreasing blend level in order level surfaces, low scaffold.

The blend level decreases on surfaces in this order:

  • Surfaces & dialogs (2x)
  • Scaffold background (1/2x)

NOTE: Since Flutter 3.22 deprecated the background color, this mode in FCS 8.0 and Flutter 3.22, sets surface and dialog blends to 2x so that it represents the "high background" style as before, but done via surface. Without this breaking change this mode would produce the same result levelSurfacesLowScaffold and be redundant.

highSurfaceLowScaffold → const FlexSurfaceMode

Decreasing blend level in order high surface, low scaffold.

The blend level decreases on surfaces in this order:

  • Surfaces & dialogs (3/2x)
  • Scaffold (1/2x)
highScaffoldLowSurface → const FlexSurfaceMode

Decreasing blend level in order very high scaffold, low surfaces.

The blend level decreases on surfaces in this order:

  • Scaffold (3x)
  • Surface & dialogs (1/2x)
highScaffoldLevelSurface → const FlexSurfaceMode

Decreasing blend level in order very high scaffold, levl surface.

The blend level decreases on surfaces in this order:

  • Scaffold (3x)
  • Surfaces & dialogs (1x)
levelSurfacesLowScaffold → const FlexSurfaceMode

Decreasing blend level in order level surfaces, low scaffold.

The blend level decreases on surfaces in this order:

  • Surfaces & dialogs (1x)
  • Scaffold (1/2x)
highScaffoldLowSurfaces → const FlexSurfaceMode

Decreasing blend level in order very high scaffold, low surfaces.

The blend level decreases on surfaces in this order:

  • Scaffold (3x)
  • Surfaces & dialogs (1/2x)
levelSurfacesLowScaffoldVariantDialog → const FlexSurfaceMode

Decreasing blend level in order level surfaces, low scaffold.

The blend level decreases on surfaces in this order:

  • Surfaces & dialogs (1x)
  • Scaffold (1/2x)

Theme ColorScheme surfaceTint color is used as blend color by default, but dialog background color uses theme ColorScheme tertiaryContainer as its blend color.

highScaffoldLowSurfacesVariantDialog → const FlexSurfaceMode

Decreasing blend level in order very high scaffold, low surface.

The blend level decreases on surfaces in this order:

  • Scaffold (3x)
  • Surfaces & dialogs (1/2x)

Theme ColorScheme surfaceTint color is used as blend color by default, but dialog background color uses theme ColorScheme tertiaryContainer as its blend color.

custom → const FlexSurfaceMode

Use your own custom surface and background blend style.

Use this option and use the FlexSchemeSurfaceColors.blend constructor to make your custom surface colors using the applied blend levels.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<FlexSurfaceMode>
A constant List of the values in this enum, in order of their declaration.